@@ -9,7 +9,7 @@ use POSIX qw(setlocale strftime LC_TIME);
 
 my $VERSION_RE = qr{\W*\b(\d+\.[\d_]+)\b};
 
-my %FILENAMES = (changelog => [qw(CHANGELOG.md Changes)], readme => [qw(README.md README)]);
+my %FILENAMES = (changelog => [qw(CHANGELOG.md Changes)]);
 
 has main_module_path => sub {
   my $self = shift;
@@ -49,8 +49,7 @@ has project_name => sub {
 has _cpanfile => sub { Module::CPANfile->load; };
 
 sub build {
-  my $self   = shift;
-  my $readme = $self->_filename('readme');
+  my $self = shift;
 
   $self->clean(0);
   $self->system(prove => split /\s/, $self->config->{build_test_options})
@@ -60,8 +59,6 @@ sub build {
   $self->_render_makefile_pl;
   $self->_timestamp_to_changes;
   $self->_update_version_info;
-  $self->system(sprintf '%s %s > %s', 'perldoc -tT', $self->main_module_path, $readme)
-    if $readme eq 'README';
   $self->_make('manifest');
   $self->_make('dist');
   $self->run_hook('after_build');
@@ -161,8 +158,6 @@ sub start {
     }
   }
 
-  symlink $self->main_module_path, 'README.pod' unless -e 'README.pod';
-
   $self->SUPER::start(@_);
   $self->render('cpanfile');
   $self->render('Changes') if $changelog eq 'Changes';
@@ -192,17 +187,13 @@ sub test_coverage {
 sub update {
   my $self    = shift;
   my $changes = $self->_filename('changelog');
-  my $readme  = $self->_filename('readme');
 
   $self->abort("Cannot update with .git directory. Forgot to run 'git ship start'?")
     unless -d '.git';
 
-  symlink $self->main_module_path, 'README.pod' unless -e 'README.pod';
   $self->_render_makefile_pl;
   $self->_update_changes if $changes eq 'Changes';
   $self->render('t/00-basic.t', {force => 1});
-  $self->system(sprintf '%s %s > %s', 'perldoc -tT', $self->main_module_path, $readme)
-    if $readme eq 'README';
   $self;
 }
 
@@ -284,13 +275,13 @@ sub _render_makefile_pl {
   my $self    = shift;
   my $prereqs = $self->_cpanfile->prereqs;
   my $args    = {force => 1};
+  my $r;
 
-  $args->{PREREQ_PM} = $prereqs->requirements_for(qw(runtime requires))->as_string_hash;
-
-  for my $k (qw(build test)) {
-    my $r = $prereqs->requirements_for($k, 'requires')->as_string_hash;
-    $args->{BUILD_REQUIRES}{$_} = $r->{$_} for keys %$r;
-  }
+  $args->{PREREQ_PM}      = $prereqs->requirements_for(qw(runtime requires))->as_string_hash;
+  $r                      = $prereqs->requirements_for(qw(build requires))->as_string_hash;
+  $args->{BUILD_REQUIRES} = $r;
+  $r                      = $prereqs->requirements_for(qw(test requires))->as_string_hash;
+  $args->{TEST_REQUIRES}  = $r;
 
   $self->render('Makefile.PL', $args);
   $self->system(qw(perl -c Makefile.PL));    # test Makefile.PL
@@ -434,17 +425,13 @@ Update version in main module file.
 
 =item 7.
 
-Update README with perldoc, unless another readfile file exists.
+Make MANIFEST
 
 =item 8.
 
-Make MANIFEST
-
-=item 9.
-
 Make dist file (Your-App-0.42.tar.gz)
 
-=item 10.
+=item 9.
 
 Run "after_build" L<hook|App::git::ship/Hooks>.
 
@@ -569,24 +556,40 @@ Revision history for perl distribution <%= $self->project_name =~ s!::!-!gr %>
 @@ Makefile.PL
 # Generated by git-ship. See 'git-ship --man' for help or https://github.com/jhthorsen/app-git-ship
 use ExtUtils::MakeMaker;
-WriteMakefile(
-  NAME => '<%= $_[0]->project_name %>',
-  AUTHOR => '<%= $_[0]->_author('%an <%ae>') %>',
-  LICENSE => '<%= $_[0]->config->{license} %>',
-  ABSTRACT_FROM => '<%= $_[0]->main_module_path %>',
-  VERSION_FROM => '<%= $_[0]->main_module_path %>',
-  EXE_FILES => [qw(<%= join ' ', $_[0]->exe_files %>)],
-  META_MERGE => {
+my %WriteMakefileArgs = (
+  NAME           => '<%= $_[0]->project_name %>',
+  AUTHOR         => '<%= $_[0]->_author("%an <%ae>") %>',
+  LICENSE        => '<%= $_[0]->config->{license} %>',
+  ABSTRACT_FROM  => '<%= $_[0]->main_module_path %>',
+  VERSION_FROM   => '<%= $_[0]->main_module_path %>',
+  EXE_FILES      => [qw(<%= join ' ', $_[0]->exe_files %>)],
+  BUILD_REQUIRES => <%= $_[1]->{BUILD_REQUIRES} %>,
+  TEST_REQUIRES  => <%= $_[1]->{TEST_REQUIRES} %>,
+  PREREQ_PM      => <%= $_[1]->{PREREQ_PM} %>,
+  META_MERGE     => {
     resources => {
-      bugtracker => '<%= $_[0]->config->{bugtracker} %>',
-      homepage => '<%= $_[0]->config->{homepage} %>',
-      repository => '<%= $_[0]->repository %>',
+      'dynamic_config' => 0,
+      'meta-spec'      => {version => 2},
+      'resources'      => {
+        bugtracker => {web => '<%= $_[0]->config->{bugtracker} %>'},
+        homepage   => '<%= $_[0]->config->{homepage} %>',
+        repository => {
+          type => 'git',
+          url  => '<%= $_[0]->repository %>',
+          web  => '<%= $_[0]->config->{homepage} %>',
+        },
+      },
     },
   },
-  BUILD_REQUIRES => <%= $_[1]->{BUILD_REQUIRES} %>,
-  PREREQ_PM => <%= $_[1]->{PREREQ_PM} %>,
-  test => {TESTS => (-e 'META.yml' ? 't/*.t' : 't/*.t xt/*.t')},
+  test => {S => (-e 'META.yml' ? 't/*.t' : 't/*.t xt/*.t')},
 );
+
+unless (eval { ExtUtils::MakeMaker->VERSION('6.63_03') }) {
+  my $test_requires = delete $WriteMakefileArgs{TEST_REQUIRES};
+  @{$WriteMakefileArgs{PREREQ_PM}}{keys %$test_requires} = values %$test_requires;
+}
+
+WriteMakefile(%WriteMakefileArgs);
 @@ MANIFEST.SKIP
 <%= $_[0]->_include_mskip_file %>
 \.swp$
